@@ -8,7 +8,9 @@ from notes.views import NoteList, NoteDetail
 
 urlpatterns = patterns('',
     url(r'^$', NoteList.as_view(), name='notes-index'),
+    url('^topics/$', ListView.as_view(model=Topic), name='notes-topic-list'),
+    url('^topics/(?P<slug>[+\w]+)/$', DetailView.as_view(model=Topic), name='notes-topic-detail'),
     url(r'^add/$', login_required(CreateView.as_view(model=Note), name='notes-create')),
-    url('^(?P<note_id>\d+)/$', NoteDetail.as_view(), name='notes-view'),
-    url('^(?P<note_id>\d+)/edit/$', login_required(EditView.as_view(model=Note)), name='notes-edit'),
+    url('^(?P<pk>\d+)/$', NoteDetail.as_view(), name='notes-view'),
+    url('^(?P<pk>\d+)/edit/$', login_required(EditView.as_view(model=Note)), name='notes-edit'),
 )
